Kommentar
Åtkomst till den här sidan kräver auktorisering. Du kan prova att logga in eller ändra kataloger.
Åtkomst till den här sidan kräver auktorisering. Du kan prova att ändra kataloger.
Den här artikeln dokumenterar REST API-åtgärder för bild-, ljud- och videogenereringsdataplan för Azure OpenAI i förhandsversionen av v1. Information om chattavslutningar, inbäddningar, evals, filer, finjustering, svar, vektorlager och alla andra åtgärder finns i den officiella referensen för Azure OpenAI REST API.
Slutsatsdragning av dataplan
Resten av den här artikeln beskriver bild-, ljud- och videoåtgärderna i den nya förhandsversionen av API:et för förhandsversionen av Azure OpenAI-dataplanets slutsatsspecifikation. Mer information finns i livscykelguiden för API.
Det fullständiga API:et för v1 GA-dataplanet finns i referensen för det officiella Azure OpenAI REST API.
Skapa tal
POST {endpoint}/openai/v1/audio/speech?api-version=preview
Genererar text-till-tal-ljud från indatatexten.
URI parametrar
| Name | I | Obligatoriskt | Type | Description |
|---|---|---|---|---|
| slutpunkt | path | Ja | string url |
Stöds Azure OpenAI-slutpunkter (protokoll och värdnamn, till exempel: https://aoairesource.openai.azure.com. Ersätt "aoairesource" med ditt Azure OpenAI-resursnamn). https://{your-resource-name}.openai.azure.com |
| api-version | Fråga | No | Den explicita Microsoft Foundry Models API-version som ska användas för den här begäran.v1 om inget annat anges. |
Begärandehuvud
Använd antingen tokenbaserad autentisering eller API-nyckel. Autentisering med tokenbaserad autentisering rekommenderas och säkrare.
| Name | Obligatoriskt | Type | Description |
|---|---|---|---|
| Authorization | True | string |
Exempel:Authorization: Bearer {Azure_OpenAI_Auth_Token}Skapa en autentiseringstoken med Azure CLI: az account get-access-token --resource https://cognitiveservices.azure.comTyp: oauth2 Auktoriserings-URL: https://login.microsoftonline.com/common/oauth2/v2.0/authorizeOmfattning: https://ai.azure.com/.default |
| API-nyckel | True | string | Ange Azure OpenAI API-nyckel här |
Begärandekropp
Innehållstyp: flera delar/formulärdata
| Name | Type | Description | Obligatoriskt | Standardinställning |
|---|---|---|---|---|
| input | string | Texten som ska genereras för. Den maximala längden är 4 096 tecken. | Ja | |
| instructions | string | Kontrollera rösten för ditt genererade ljud med ytterligare instruktioner. Fungerar inte med tts-1 eller tts-1-hd. |
No | |
| model | string | Den modell som ska användas för den här text-till-tal-begäran. | Ja | |
| svarsformat | object | De ljudutdataformat som stöds för text till tal. | No | |
| Hastighet | number | Talhastigheten för genererat ljud. Värdena är giltiga i intervallet från 0,25 till 4,0, med 1,0 standardvärden och högre värden som motsvarar snabbare tal. | No | 1 |
| stream_format | enum | Formatet för att strömma ljudet i. Format som stöds är sse och audio.
sse stöds inte för tts-1 eller tts-1-hd.Möjliga värden: sse, audio |
No | |
| Röst | object | Ja |
Responses
Statuskod: 200
Beskrivning: Begäran har slutförts.
| Innehållstyp | Type | Beskrivning |
|---|---|---|
| application/octet-stream | string |
Statuskod: standard
Beskrivning: Ett oväntat felsvar.
| Innehållstyp | Type | Beskrivning |
|---|---|---|
| application/json | AzureErrorResponse |
Exempel
Example
Syntetiserar ljud från den angivna texten.
POST {endpoint}/openai/v1/audio/speech?api-version=preview
{
"input": "Hi! What are you going to make?",
"voice": "fable",
"response_format": "mp3",
"model": "tts-1"
}
Svar: Statuskod: 200
{
"body": "101010101"
}
Skapa transkription
POST {endpoint}/openai/v1/audio/transcriptions?api-version=preview
Transkriberar ljud till indataspråket.
URI parametrar
| Name | I | Obligatoriskt | Type | Description |
|---|---|---|---|---|
| slutpunkt | path | Ja | string url |
Stöds Azure OpenAI-slutpunkter (protokoll och värdnamn, till exempel: https://aoairesource.openai.azure.com. Ersätt "aoairesource" med ditt Azure OpenAI-resursnamn). https://{your-resource-name}.openai.azure.com |
| api-version | Fråga | No | Den explicita Foundry Models API-versionen som ska användas för den här begäran.v1 om inget annat anges. |
Begärandehuvud
Använd antingen tokenbaserad autentisering eller API-nyckel. Autentisering med tokenbaserad autentisering rekommenderas och säkrare.
| Name | Obligatoriskt | Type | Description |
|---|---|---|---|
| Authorization | True | string |
Exempel:Authorization: Bearer {Azure_OpenAI_Auth_Token}Skapa en autentiseringstoken med Azure CLI: az account get-access-token --resource https://cognitiveservices.azure.comTyp: oauth2 Auktoriserings-URL: https://login.microsoftonline.com/common/oauth2/v2.0/authorizeOmfattning: https://ai.azure.com/.default |
| API-nyckel | True | string | Ange Azure OpenAI API-nyckel här |
Begärandekropp
Innehållstyp: flera delar/formulärdata
| Name | Type | Description | Obligatoriskt | Standardinställning |
|---|---|---|---|---|
| chunking_strategy | object | No | ||
| └– prefix_padding_ms | integer | Mängden ljud som ska inkluderas innan VAD identifierade tal (i millisekunder). | No | 300 |
| └ silence_duration_ms | integer | Varaktighet för tystnad för att identifiera talstopp (i millisekunder). Med kortare värden svarar modellen snabbare, men kan hoppa in vid korta pauser från användaren. | No | 200 |
| └– tröskelvärde | number | Känslighetströskel (0,0 till 1,0) för identifiering av röstaktivitet. Ett högre tröskelvärde kräver högre ljud för att aktivera modellen och kan därför fungera bättre i bullriga miljöer. | No | 0,5 |
| └– typ | enum | Måste anges till server_vad för att aktivera manuell segmentering med hjälp av VAD på serversidan.Möjliga värden: server_vad |
No | |
| fil | string | Ja | ||
| filename | string | Det valfria filnamnet eller den beskrivande identifieraren som ska associeras med ljuddata. | No | |
| include[] | array | Ytterligare information som ska ingå i transkriptionssvaret.
logprobs returnerar loggannolikorna för token i svaret för att förstå modellens förtroende för transkriptionen.
logprobs fungerar endast med response_format inställt på json och endast med modellerna gpt-4o-transcribe, gpt-4o-transcribe-diarize, gpt-4o-mini-transcribeoch gpt-4o-mini-transcribe-2025-12-15. |
No | |
| language | string | Språket för indataljudet. Om du anger indataspråket i FORMATET ISO-639-1 (t.ex. en) förbättras noggrannheten och svarstiden. |
No | |
| model | string | Den modell som ska användas för den här transkriptionsbegäran. | No | |
| prompt | string | En valfri text som vägleder modellens formatmall eller fortsätter med ett tidigare ljudsegment. Uppmaningen ska matcha ljudspråket. | No | |
| svarsformat | object | No | ||
| stream | boolean | Om värdet är true strömmas modellsvarsdata till klienten när de genereras med hjälp av serverutskickade händelser. Obs! Direktuppspelning stöds inte för whisper-1 modellen och ignoreras. |
No | Falsk |
| Temperatur | number | Provtagningstemperaturen, mellan 0 och 1. Högre värden som 0,8 gör utdata mer slumpmässiga, medan lägre värden som 0,2 gör det mer fokuserat och deterministiskt. Om värdet är 0 använder modellen loggsannolikhet för att automatiskt öka temperaturen tills vissa tröskelvärden uppnås. | No | 0 |
| timestamp_granularities[] | array | Tidsstämpelkornigheterna som ska fyllas i för den här transkriptionen.
response_format måste anges verbose_json för att använda tidsstämpelkornigheter. Något av eller båda alternativen stöds: word, eller segment. Obs! Det finns ingen ytterligare svarstid för segmenttidsstämplar, men att generera ordtidsstämplar medför ytterligare svarstid. |
No | ['segment'] |
Responses
Statuskod: 200
Beskrivning: Begäran har slutförts.
| Innehållstyp | Type | Beskrivning |
|---|---|---|
| application/json | AzureAudioTranscriptionResponse | |
| text/plain | string |
Statuskod: standard
Beskrivning: Ett oväntat felsvar.
| Innehållstyp | Type | Beskrivning |
|---|---|---|
| application/json | AzureErrorResponse |
Exempel
Example
Hämtar transkriberad text och associerade metadata från angivna talade ljuddata.
POST {endpoint}/openai/v1/audio/transcriptions?api-version=preview
{
"file": "<binary audio data>",
"model": "whisper-1",
"response_format": "text"
}
Svar: Statuskod: 200
{
"body": "plain text when requesting text, srt, or vtt"
}
Skapa översättning
POST {endpoint}/openai/v1/audio/translations?api-version=preview
Hämtar engelskspråkig transkriberad text och associerade metadata från angivna talade ljuddata.
URI parametrar
| Name | I | Obligatoriskt | Type | Description |
|---|---|---|---|---|
| slutpunkt | path | Ja | string url |
Stöds Azure OpenAI-slutpunkter (protokoll och värdnamn, till exempel: https://aoairesource.openai.azure.com. Ersätt "aoairesource" med ditt Azure OpenAI-resursnamn). https://{your-resource-name}.openai.azure.com |
| api-version | Fråga | No | Den explicita Foundry Models API-versionen som ska användas för den här begäran.v1 om inget annat anges. |
Begärandehuvud
Använd antingen tokenbaserad autentisering eller API-nyckel. Autentisering med tokenbaserad autentisering rekommenderas och säkrare.
| Name | Obligatoriskt | Type | Description |
|---|---|---|---|
| Authorization | True | string |
Exempel:Authorization: Bearer {Azure_OpenAI_Auth_Token}Skapa en autentiseringstoken med Azure CLI: az account get-access-token --resource https://cognitiveservices.azure.comTyp: oauth2 Auktoriserings-URL: https://login.microsoftonline.com/common/oauth2/v2.0/authorizeOmfattning: https://ai.azure.com/.default |
| API-nyckel | True | string | Ange Azure OpenAI API-nyckel här |
Begärandekropp
Innehållstyp: flera delar/formulärdata
| Name | Type | Description | Obligatoriskt | Standardinställning |
|---|---|---|---|---|
| fil | string | Ja | ||
| filename | string | Det valfria filnamnet eller den beskrivande identifieraren som ska associeras med ljuddata | No | |
| model | string | Den modell som ska användas för den här översättningsbegäran. | No | |
| prompt | string | En valfri text som vägleder modellens formatmall eller fortsätter med ett tidigare ljudsegment. Uppmaningen ska vara på engelska. | No | |
| svarsformat | object | No | ||
| Temperatur | number | Provtagningstemperaturen, mellan 0 och 1. Högre värden som 0,8 gör utdata mer slumpmässiga, medan lägre värden som 0,2 gör det mer fokuserat och deterministiskt. Om värdet är 0 använder modellen loggsannolikhet för att automatiskt öka temperaturen tills vissa tröskelvärden uppnås. | No | 0 |
Responses
Statuskod: 200
Beskrivning: Begäran har slutförts.
| Innehållstyp | Type | Beskrivning |
|---|---|---|
| application/json | AzureAudioTranslationResponse | |
| text/plain | string |
Statuskod: standard
Beskrivning: Ett oväntat felsvar.
| Innehållstyp | Type | Beskrivning |
|---|---|---|
| application/json | AzureErrorResponse |
Exempel
Example
Hämtar engelskspråkig transkriberad text och associerade metadata från angivna talade ljuddata.
POST {endpoint}/openai/v1/audio/translations?api-version=preview
{
"file": "<binary audio data>",
"model": "whisper-1",
"response_format": "text"
}
Svar: Statuskod: 200
{
"body": "plain text when requesting text, srt, or vtt"
}
Skapa bildredigering
POST {endpoint}/openai/v1/images/edits?api-version=preview
URI parametrar
| Name | I | Obligatoriskt | Type | Description |
|---|---|---|---|---|
| slutpunkt | path | Ja | string url |
Stöds Azure OpenAI-slutpunkter (protokoll och värdnamn, till exempel: https://aoairesource.openai.azure.com. Ersätt "aoairesource" med ditt Azure OpenAI-resursnamn). https://{your-resource-name}.openai.azure.com |
| api-version | Fråga | No | Den explicita Foundry Models API-versionen som ska användas för den här begäran.v1 om inget annat anges. |
Begärandehuvud
Använd antingen tokenbaserad autentisering eller API-nyckel. Autentisering med tokenbaserad autentisering rekommenderas och säkrare.
| Name | Obligatoriskt | Type | Description |
|---|---|---|---|
| Authorization | True | string |
Exempel:Authorization: Bearer {Azure_OpenAI_Auth_Token}Skapa en autentiseringstoken med Azure CLI: az account get-access-token --resource https://cognitiveservices.azure.comTyp: oauth2 Auktoriserings-URL: https://login.microsoftonline.com/common/oauth2/v2.0/authorizeOmfattning: https://ai.azure.com/.default |
| API-nyckel | True | string | Ange Azure OpenAI API-nyckel här |
Begärandekropp
Innehållstyp: flera delar/formulärdata
| Name | Type | Description | Obligatoriskt | Standardinställning |
|---|---|---|---|---|
| bakgrund | enum | Gör att du kan ange transparens för bakgrunden för de genererade avbildningarna. Den här parametern stöds endast för gpt-image-1 modeller. Måste vara ett av transparent, opaque eller auto (standardvärde). När auto används avgör modellen automatiskt den bästa bakgrunden för bilden.Om transparentmåste utdataformatet ha stöd för transparens, så det bör anges till antingen png (standardvärde) eller webp.Möjliga värden: transparent, opaque, auto |
No | |
| bild | sträng eller matris | Ja | ||
| mask | string | No | ||
| model | string | Modelldistributionen som ska användas för avbildningsredigeringsåtgärden. | Ja | |
| n | integer | Antalet bilder som ska genereras. Måste vara mellan 1 och 10. | No | 1 |
| Utdata kompression | integer | Komprimeringsnivån (0–100%) för de genererade bilderna. Den här parametern stöds endast för gpt-image-1-series-modeller med utdataformaten webp eller jpeg och är som standard 100. |
No | 100 |
| output_format | enum | Formatet där de genererade bilderna returneras. Den här parametern stöds endast för gpt-image-1-series-modeller. Måste vara en av png, jpegeller webp.Standardvärdet är png.Möjliga värden: png, jpeg, webp |
No | |
| prompt | string | En textbeskrivning av de önskade bilderna. Den maximala längden är 1 000 tecken för dall-e-2och 32 000 tecken för gpt-image-1-seriemodeller. |
Ja | |
| kvalitet | enum | Kvaliteten på den bild som ska genereras.
highoch mediumlow stöds endast för gpt-image-1-series-modeller.
dall-e-2 stöder standard endast kvalitet. Standardvärdet är auto.Möjliga värden: standard, low, medium, , highauto |
No | |
| svarsformat | enum | Formatet där de genererade bilderna returneras. Måste vara en av url eller b64_json. URL:er är endast giltiga i 60 minuter efter att avbildningen har genererats. Den här parametern stöds bara för dall-e-2, eftersom gpt-image-1-series-modeller alltid returnerar base64-kodade bilder.Möjliga värden: url, b64_json |
No | |
| size | enum | Storleken på de genererade bilderna. Måste vara en av 1024x1024, 1536x1024 (liggande), 1024x1536 (stående) eller auto (standardvärde) för gpt-image-1-series-modeller och en av 256x256, 512x512eller 1024x1024 för dall-e-2.Möjliga värden: 256x256, 512x512, 1024x1024, 1536x1024, , 1024x1536auto |
No | |
| user | string | En unik identifierare som representerar slutanvändaren, som kan hjälpa OpenAI att övervaka och upptäcka missbruk. | No |
Responses
Statuskod: 200
Beskrivning: Begäran har slutförts.
| Innehållstyp | Type | Beskrivning |
|---|---|---|
| application/json | AzureImagesResponse |
Statuskod: standard
Beskrivning: Ett oväntat felsvar.
| Innehållstyp | Type | Beskrivning |
|---|---|---|
| application/json | AzureErrorResponse |
Skapaimage
POST {endpoint}/openai/v1/images/generations?api-version=preview
URI parametrar
| Name | I | Obligatoriskt | Type | Description |
|---|---|---|---|---|
| slutpunkt | path | Ja | string url |
Stöds Azure OpenAI-slutpunkter (protokoll och värdnamn, till exempel: https://aoairesource.openai.azure.com. Ersätt "aoairesource" med ditt Azure OpenAI-resursnamn). https://{your-resource-name}.openai.azure.com |
| api-version | Fråga | No | Den explicita Foundry Models API-versionen som ska användas för den här begäran.v1 om inget annat anges. |
Begärandehuvud
Använd antingen tokenbaserad autentisering eller API-nyckel. Autentisering med tokenbaserad autentisering rekommenderas och säkrare.
| Name | Obligatoriskt | Type | Description |
|---|---|---|---|
| Authorization | True | string |
Exempel:Authorization: Bearer {Azure_OpenAI_Auth_Token}Skapa en autentiseringstoken med Azure CLI: az account get-access-token --resource https://cognitiveservices.azure.comTyp: oauth2 Auktoriserings-URL: https://login.microsoftonline.com/common/oauth2/v2.0/authorizeOmfattning: https://ai.azure.com/.default |
| API-nyckel | True | string | Ange Azure OpenAI API-nyckel här |
Begärandekropp
Innehållstyp: program/json
| Name | Type | Description | Obligatoriskt | Standardinställning |
|---|---|---|---|---|
| bakgrund | enum | Gör att du kan ange transparens för bakgrunden för de genererade avbildningarna. Den här parametern stöds endast för gpt-image-1 modeller. Måste vara ett av transparent, opaque eller auto (standardvärde). När auto används avgör modellen automatiskt den bästa bakgrunden för bilden.Om transparentmåste utdataformatet ha stöd för transparens, så det bör anges till antingen png (standardvärde) eller webp.Möjliga värden: transparent, opaque, auto |
No | |
| model | string | Modelldistributionen som ska användas för avbildningsgenereringen. | Ja | |
| Måtta | enum | Kontrollera nivån för innehållsmoderering för bilder som genereras av gpt-image-1-series-modeller. Måste vara antingen low för mindre restriktiv filtrering eller auto (standardvärde).Möjliga värden: low, auto |
No | |
| n | integer | Antalet bilder som ska genereras. Måste vara mellan 1 och 10. För dall-e-3stöds endast n=1 . |
No | 1 |
| Utdata kompression | integer | Komprimeringsnivån (0–100%) för de genererade bilderna. Den här parametern stöds endast för gpt-image-1-series-modeller med utdataformaten webp eller jpeg och är som standard 100. |
No | 100 |
| output_format | enum | Formatet där de genererade bilderna returneras. Den här parametern stöds endast för gpt-image-1-series-modeller. Måste vara en av png, jpegeller webp.Möjliga värden: png, jpeg, webp |
No | |
| prompt | string | En textbeskrivning av de önskade bilderna. Den maximala längden är 32 000 tecken för gpt-image-1-seriemodeller, 1 000 tecken för dall-e-2 och 4 000 tecken för dall-e-3. |
Ja | |
| kvalitet | enum | Kvaliteten på den bild som ska genereras. - auto (standardvärde) väljer automatiskt den bästa kvaliteten för den angivna modellen.- high, medium och low stöds för gpt-image-1-series-modeller.- hd och standard stöds för dall-e-3.- standard är det enda alternativet för dall-e-2.Möjliga värden: standard, hd, low, medium, , highauto |
No | |
| svarsformat | enum | Formatet där genererade bilder med dall-e-2 och dall-e-3 returneras. Måste vara en av url eller b64_json. URL:er är endast giltiga i 60 minuter efter att avbildningen har genererats. Den här parametern stöds inte för gpt-image-1-series-modeller som alltid returnerar base64-kodade bilder.Möjliga värden: url, b64_json |
No | |
| size | enum | Storleken på de genererade bilderna. Måste vara en av 1024x1024, 1536x1024 (liggande), 1024x1536 (stående) eller auto (standardvärde) för gpt-image-1-seriemodeller, en av 256x256, 512x512, eller 1024x1024 för dall-e-2, och en av 1024x1024, 1792x1024eller 1024x1792 för dall-e-3.Möjliga värden: auto, 1024x1024, 1536x1024, 1024x1536, 256x256, 512x512, , , 1792x10241024x1792 |
No | |
| Stil | enum | Formatmallen för de genererade bilderna. Den här parametern stöds endast för dall-e-3. Måste vara en av vivid eller natural. Levande gör att modellen lutar sig mot att generera hyperreella och dramatiska bilder. Naturliga orsaker till att modellen producerar mer naturliga, mindre hyper-verkliga bilder.Möjliga värden: vivid, natural |
No | |
| user | string | En unik identifierare som representerar slutanvändaren, som kan hjälpa OpenAI att övervaka och upptäcka missbruk. | No |
Responses
Statuskod: 200
Beskrivning: Begäran har slutförts.
| Innehållstyp | Type | Beskrivning |
|---|---|---|
| application/json | AzureImagesResponse |
Statuskod: standard
Beskrivning: Ett oväntat felsvar.
| Innehållstyp | Type | Beskrivning |
|---|---|---|
| application/json | AzureErrorResponse |
Exempel
Example
Skapar avbildningar med en uppmaning.
POST {endpoint}/openai/v1/images/generations?api-version=preview
{
"model": "dall-e-3",
"prompt": "In the style of WordArt, Microsoft Clippy wearing a cowboy hat.",
"n": 1,
"style": "natural",
"quality": "standard"
}
Svar: Statuskod: 200
{
"body": {
"created": 1698342300,
"data": [
{
"revised_prompt": "A vivid, natural representation of Microsoft Clippy wearing a cowboy hat.",
"prompt_filter_results": {
"sexual": {
"severity": "safe",
"filtered": false
},
"violence": {
"severity": "safe",
"filtered": false
},
"hate": {
"severity": "safe",
"filtered": false
},
"self_harm": {
"severity": "safe",
"filtered": false
},
"profanity": {
"detected": false,
"filtered": false
},
"custom_blocklists": {
"filtered": false,
"details": []
}
},
"url": "https://dalletipusw2.blob.core.windows.net/private/images/e5451cc6-b1ad-4747-bd46-b89a3a3b8bc3/generated_00.png?se=2023-10-27T17%3A45%3A09Z&...",
"content_filter_results": {
"sexual": {
"severity": "safe",
"filtered": false
},
"violence": {
"severity": "safe",
"filtered": false
},
"hate": {
"severity": "safe",
"filtered": false
},
"self_harm": {
"severity": "safe",
"filtered": false
}
}
}
]
}
}
Videogenereringsjobb – Skapa
POST {endpoint}/openai/v1/video/generations/jobs?api-version=preview
Skapar ett nytt videogenereringsjobb.
URI parametrar
| Name | I | Obligatoriskt | Type | Description |
|---|---|---|---|---|
| slutpunkt | path | Ja | string url |
Stöds Azure OpenAI-slutpunkter (protokoll och värdnamn, till exempel: https://aoairesource.openai.azure.com. Ersätt "aoairesource" med ditt Azure OpenAI-resursnamn). https://{your-resource-name}.openai.azure.com |
| api-version | Fråga | No | Den explicita Foundry Models API-versionen som ska användas för den här begäran.v1 om inget annat anges. |
Begärandehuvud
Använd antingen tokenbaserad autentisering eller API-nyckel. Autentisering med tokenbaserad autentisering rekommenderas och säkrare.
| Name | Obligatoriskt | Type | Description |
|---|---|---|---|
| Authorization | True | string |
Exempel:Authorization: Bearer {Azure_OpenAI_Auth_Token}Skapa en autentiseringstoken med Azure CLI: az account get-access-token --resource https://cognitiveservices.azure.comTyp: oauth2 Auktoriserings-URL: https://login.microsoftonline.com/common/oauth2/v2.0/authorizeOmfattning: https://ai.azure.com/.default |
| API-nyckel | True | string | Ange Azure OpenAI API-nyckel här |
Begärandekropp
Innehållstyp: program/json
| Name | Type | Description | Obligatoriskt | Standardinställning |
|---|---|---|---|---|
| height | integer | Videons höjd. Följande dimensioner stöds: 480x480, 854x480, 720x720, 1280x720, 1080x1080 och 1920x1080 i både liggande och stående orienteringar. | Ja | |
| model | string | Namnet på distributionen som ska användas för den här begäran. | Ja | |
| n_seconds | integer | Varaktigheten för videogenereringsjobbet. Måste vara mellan 1 och 20 sekunder. | No | 5 |
| n_variants | integer | Antalet videor som ska skapas som varianter för det här jobbet. Måste vara mellan 1 och 5. Mindre dimensioner tillåter fler varianter. | No | 1 |
| prompt | string | Uppmaningen för det här videogenereringsjobbet. | Ja | |
| width | integer | Videons bredd. Följande dimensioner stöds: 480x480, 854x480, 720x720, 1280x720, 1080x1080 och 1920x1080 i både liggande och stående orienteringar. | Ja |
Begärandekropp
Innehållstyp: flera delar/formulärdata
| Name | Type | Description | Obligatoriskt | Standardinställning |
|---|---|---|---|---|
| files | array | Ja | ||
| height | integer | Videons höjd. Följande dimensioner stöds: 480x480, 854x480, 720x720, 1280x720, 1080x1080 och 1920x1080 i både liggande och stående orienteringar. | Ja | |
| inpaint_items | array | Valfria inpainting-objekt för det här videogenereringsjobbet. | No | |
| model | string | Namnet på distributionen som ska användas för den här begäran. | Ja | |
| n_seconds | integer | Varaktigheten för videogenereringsjobbet. Måste vara mellan 1 och 20 sekunder. | No | 5 |
| n_variants | integer | Antalet videor som ska skapas som varianter för det här jobbet. Måste vara mellan 1 och 5. Mindre dimensioner tillåter fler varianter. | No | 1 |
| prompt | string | Uppmaningen för det här videogenereringsjobbet. | Ja | |
| width | integer | Videons bredd. Följande dimensioner stöds: 480x480, 854x480, 720x720, 1280x720, 1080x1080 och 1920x1080 i både liggande och stående orienteringar. | Ja |
Responses
Statuskod: 200
Beskrivning: Begäran har slutförts.
| Innehållstyp | Type | Beskrivning |
|---|---|---|
| application/json | VideoGenerationJob |
Statuskod: standard
Beskrivning: Ett oväntat felsvar.
| Innehållstyp | Type | Beskrivning |
|---|---|---|
| application/json | AzureOpenAIVideoGenerationErrorResponse |
Exempel
Det går inte att hitta exempelfilen: ./examples/create_video_generation_job_simple.json
Videogenereringsjobb – lista
GET {endpoint}/openai/v1/video/generations/jobs?api-version=preview
Visar en lista över videogenereringsjobb.
URI parametrar
| Name | I | Obligatoriskt | Type | Description |
|---|---|---|---|---|
| slutpunkt | path | Ja | string url |
Stöds Azure OpenAI-slutpunkter (protokoll och värdnamn, till exempel: https://aoairesource.openai.azure.com. Ersätt "aoairesource" med ditt Azure OpenAI-resursnamn). https://{your-resource-name}.openai.azure.com |
| api-version | Fråga | No | Den explicita Foundry Models API-versionen som ska användas för den här begäran.v1 om inget annat anges. |
|
| före | Fråga | No | string | |
| Efter | Fråga | No | string | |
| limit | Fråga | Ja | integer | |
| statuses | Fråga | No | array |
Begärandehuvud
Använd antingen tokenbaserad autentisering eller API-nyckel. Autentisering med tokenbaserad autentisering rekommenderas och säkrare.
| Name | Obligatoriskt | Type | Description |
|---|---|---|---|
| Authorization | True | string |
Exempel:Authorization: Bearer {Azure_OpenAI_Auth_Token}Skapa en autentiseringstoken med Azure CLI: az account get-access-token --resource https://cognitiveservices.azure.comTyp: oauth2 Auktoriserings-URL: https://login.microsoftonline.com/common/oauth2/v2.0/authorizeOmfattning: https://ai.azure.com/.default |
| API-nyckel | True | string | Ange Azure OpenAI API-nyckel här |
Responses
Statuskod: 200
Beskrivning: Begäran har slutförts.
| Innehållstyp | Type | Beskrivning |
|---|---|---|
| application/json | VideoGenerationJobList |
Statuskod: standard
Beskrivning: Ett oväntat felsvar.
| Innehållstyp | Type | Beskrivning |
|---|---|---|
| application/json | AzureOpenAIVideoGenerationErrorResponse |
Exempel
Det går inte att hitta exempelfilen: ./examples/get_video_generation_job_list.json
Videogenereringsjobb – Hämta
GET {endpoint}/openai/v1/video/generations/jobs/{job-id}?api-version=preview
Hämtar egenskaper för ett videogenereringsjobb.
URI parametrar
| Name | I | Obligatoriskt | Type | Description |
|---|---|---|---|---|
| slutpunkt | path | Ja | string url |
Stöds Azure OpenAI-slutpunkter (protokoll och värdnamn, till exempel: https://aoairesource.openai.azure.com. Ersätt "aoairesource" med ditt Azure OpenAI-resursnamn). https://{your-resource-name}.openai.azure.com |
| api-version | Fråga | No | Den explicita Foundry Models API-versionen som ska användas för den här begäran.v1 om inget annat anges. |
|
| job-id | path | Ja | string | ID:t för videogenereringsjobbet som ska användas för Azure OpenAI-begäran. |
Begärandehuvud
Använd antingen tokenbaserad autentisering eller API-nyckel. Autentisering med tokenbaserad autentisering rekommenderas och säkrare.
| Name | Obligatoriskt | Type | Description |
|---|---|---|---|
| Authorization | True | string |
Exempel:Authorization: Bearer {Azure_OpenAI_Auth_Token}Skapa en autentiseringstoken med Azure CLI: az account get-access-token --resource https://cognitiveservices.azure.comTyp: oauth2 Auktoriserings-URL: https://login.microsoftonline.com/common/oauth2/v2.0/authorizeOmfattning: https://ai.azure.com/.default |
| API-nyckel | True | string | Ange Azure OpenAI API-nyckel här |
Responses
Statuskod: 200
Beskrivning: Begäran har slutförts.
| Innehållstyp | Type | Beskrivning |
|---|---|---|
| application/json | VideoGenerationJob |
Statuskod: standard
Beskrivning: Ett oväntat felsvar.
| Innehållstyp | Type | Beskrivning |
|---|---|---|
| application/json | AzureOpenAIVideoGenerationErrorResponse |
Exempel
Det går inte att hitta exempelfilen: ./examples/get_video_generation_job.json
Videogenereringsjobb – Ta bort
DELETE {endpoint}/openai/v1/video/generations/jobs/{job-id}?api-version=preview
Tar bort ett videogenereringsjobb.
URI parametrar
| Name | I | Obligatoriskt | Type | Description |
|---|---|---|---|---|
| slutpunkt | path | Ja | string url |
Stöds Azure OpenAI-slutpunkter (protokoll och värdnamn, till exempel: https://aoairesource.openai.azure.com. Ersätt "aoairesource" med ditt Azure OpenAI-resursnamn). https://{your-resource-name}.openai.azure.com |
| api-version | Fråga | No | Den explicita Foundry Models API-versionen som ska användas för den här begäran.v1 om inget annat anges. |
|
| job-id | path | Ja | string | ID:t för videogenereringsjobbet som ska användas för Azure OpenAI-begäran. |
Begärandehuvud
Använd antingen tokenbaserad autentisering eller API-nyckel. Autentisering med tokenbaserad autentisering rekommenderas och säkrare.
| Name | Obligatoriskt | Type | Description |
|---|---|---|---|
| Authorization | True | string |
Exempel:Authorization: Bearer {Azure_OpenAI_Auth_Token}Skapa en autentiseringstoken med Azure CLI: az account get-access-token --resource https://cognitiveservices.azure.comTyp: oauth2 Auktoriserings-URL: https://login.microsoftonline.com/common/oauth2/v2.0/authorizeOmfattning: https://ai.azure.com/.default |
| API-nyckel | True | string | Ange Azure OpenAI API-nyckel här |
Responses
Statuskod: 204
Beskrivning: Det finns inget innehåll att skicka för den här begäran, men rubrikerna kan vara användbara.
Statuskod: standard
Beskrivning: Ett oväntat felsvar.
| Innehållstyp | Type | Beskrivning |
|---|---|---|
| application/json | AzureOpenAIVideoGenerationErrorResponse |
Videogenerationer – Hämta
GET {endpoint}/openai/v1/video/generations/{generation-id}?api-version=preview
Hämtar en videogenerering efter ID.
URI parametrar
| Name | I | Obligatoriskt | Type | Description |
|---|---|---|---|---|
| slutpunkt | path | Ja | string url |
Stöds Azure OpenAI-slutpunkter (protokoll och värdnamn, till exempel: https://aoairesource.openai.azure.com. Ersätt "aoairesource" med ditt Azure OpenAI-resursnamn). https://{your-resource-name}.openai.azure.com |
| api-version | Fråga | No | Den explicita Foundry Models API-versionen som ska användas för den här begäran.v1 om inget annat anges. |
|
| generation-id | path | Ja | string | ID:t för videogenerationen som ska användas för Azure OpenAI-begäran. |
Begärandehuvud
Använd antingen tokenbaserad autentisering eller API-nyckel. Autentisering med tokenbaserad autentisering rekommenderas och säkrare.
| Name | Obligatoriskt | Type | Description |
|---|---|---|---|
| Authorization | True | string |
Exempel:Authorization: Bearer {Azure_OpenAI_Auth_Token}Skapa en autentiseringstoken med Azure CLI: az account get-access-token --resource https://cognitiveservices.azure.comTyp: oauth2 Auktoriserings-URL: https://login.microsoftonline.com/common/oauth2/v2.0/authorizeOmfattning: https://ai.azure.com/.default |
| API-nyckel | True | string | Ange Azure OpenAI API-nyckel här |
Responses
Statuskod: 200
Beskrivning: Begäran har slutförts.
| Innehållstyp | Type | Beskrivning |
|---|---|---|
| application/json | VideoGeneration |
Statuskod: standard
Beskrivning: Ett oväntat felsvar.
| Innehållstyp | Type | Beskrivning |
|---|---|---|
| application/json | AzureOpenAIVideoGenerationErrorResponse |
Exempel
Det går inte att hitta exempelfilen: ./examples/get_video_generation.json
Videogenerationer – Hämta miniatyrbild
GET {endpoint}/openai/v1/video/generations/{generation-id}/content/thumbnail?api-version=preview
Hämtar en miniatyrbild av det genererade videoinnehållet.
URI parametrar
| Name | I | Obligatoriskt | Type | Description |
|---|---|---|---|---|
| slutpunkt | path | Ja | string url |
Stöds Azure OpenAI-slutpunkter (protokoll och värdnamn, till exempel: https://aoairesource.openai.azure.com. Ersätt "aoairesource" med ditt Azure OpenAI-resursnamn). https://{your-resource-name}.openai.azure.com |
| api-version | Fråga | No | Den explicita Foundry Models API-versionen som ska användas för den här begäran.v1 om inget annat anges. |
|
| generation-id | path | Ja | string | ID:t för videogenerationen som ska användas för Azure OpenAI-begäran. |
Begärandehuvud
Använd antingen tokenbaserad autentisering eller API-nyckel. Autentisering med tokenbaserad autentisering rekommenderas och säkrare.
| Name | Obligatoriskt | Type | Description |
|---|---|---|---|
| Authorization | True | string |
Exempel:Authorization: Bearer {Azure_OpenAI_Auth_Token}Skapa en autentiseringstoken med Azure CLI: az account get-access-token --resource https://cognitiveservices.azure.comTyp: oauth2 Auktoriserings-URL: https://login.microsoftonline.com/common/oauth2/v2.0/authorizeOmfattning: https://ai.azure.com/.default |
| API-nyckel | True | string | Ange Azure OpenAI API-nyckel här |
Responses
Statuskod: 200
Beskrivning: Begäran har slutförts.
| Innehållstyp | Type | Beskrivning |
|---|---|---|
| bild/jpg | string |
Statuskod: standard
Beskrivning: Ett oväntat felsvar.
| Innehållstyp | Type | Beskrivning |
|---|---|---|
| application/json | AzureOpenAIVideoGenerationErrorResponse |
Videogenerationer – Hämta videoinnehåll
GET {endpoint}/openai/v1/video/generations/{generation-id}/content/video?api-version=preview
Hämtar det genererade videoinnehållet.
URI parametrar
| Name | I | Obligatoriskt | Type | Description |
|---|---|---|---|---|
| slutpunkt | path | Ja | string url |
Stöds Azure OpenAI-slutpunkter (protokoll och värdnamn, till exempel: https://aoairesource.openai.azure.com. Ersätt "aoairesource" med ditt Azure OpenAI-resursnamn). https://{your-resource-name}.openai.azure.com |
| api-version | Fråga | No | Den explicita Foundry Models API-versionen som ska användas för den här begäran.v1 om inget annat anges. |
|
| generation-id | path | Ja | string | ID:t för videogenerationen som ska användas för Azure OpenAI-begäran. |
| kvalitet | Fråga | No |
Begärandehuvud
Använd antingen tokenbaserad autentisering eller API-nyckel. Autentisering med tokenbaserad autentisering rekommenderas och säkrare.
| Name | Obligatoriskt | Type | Description |
|---|---|---|---|
| Authorization | True | string |
Exempel:Authorization: Bearer {Azure_OpenAI_Auth_Token}Skapa en autentiseringstoken med Azure CLI: az account get-access-token --resource https://cognitiveservices.azure.comTyp: oauth2 Auktoriserings-URL: https://login.microsoftonline.com/common/oauth2/v2.0/authorizeOmfattning: https://ai.azure.com/.default |
| API-nyckel | True | string | Ange Azure OpenAI API-nyckel här |
Responses
Statuskod: 200
Beskrivning: Begäran har slutförts.
| Innehållstyp | Type | Beskrivning |
|---|---|---|
| video/mp4 | string |
Statuskod: standard
Beskrivning: Ett oväntat felsvar.
| Innehållstyp | Type | Beskrivning |
|---|---|---|
| application/json | AzureOpenAIVideoGenerationErrorResponse |
Videogenerationer – Hämta endast videoinnehållshuvuden
HEAD {endpoint}/openai/v1/video/generations/{generation-id}/content/video?api-version=preview
Hämtar rubriker för det genererade videoinnehållet.
URI parametrar
| Name | I | Obligatoriskt | Type | Description |
|---|---|---|---|---|
| slutpunkt | path | Ja | string url |
Stöds Azure OpenAI-slutpunkter (protokoll och värdnamn, till exempel: https://aoairesource.openai.azure.com. Ersätt "aoairesource" med ditt Azure OpenAI-resursnamn). https://{your-resource-name}.openai.azure.com |
| api-version | Fråga | No | Den explicita Foundry Models API-versionen som ska användas för den här begäran.v1 om inget annat anges. |
|
| generation-id | path | Ja | string | ID:t för videogenerationen som ska användas för Azure OpenAI-begäran. |
| kvalitet | Fråga | No |
Begärandehuvud
Använd antingen tokenbaserad autentisering eller API-nyckel. Autentisering med tokenbaserad autentisering rekommenderas och säkrare.
| Name | Obligatoriskt | Type | Description |
|---|---|---|---|
| Authorization | True | string |
Exempel:Authorization: Bearer {Azure_OpenAI_Auth_Token}Skapa en autentiseringstoken med Azure CLI: az account get-access-token --resource https://cognitiveservices.azure.comTyp: oauth2 Auktoriserings-URL: https://login.microsoftonline.com/common/oauth2/v2.0/authorizeOmfattning: https://ai.azure.com/.default |
| API-nyckel | True | string | Ange Azure OpenAI API-nyckel här |
Responses
Statuskod: 200
Beskrivning: Begäran har slutförts.
Statuskod: standard
Beskrivning: Ett oväntat felsvar.
| Innehållstyp | Type | Beskrivning |
|---|---|---|
| application/json | AzureOpenAIVideoGenerationErrorResponse |
Components
Schemadefinitioner som används av chatt, slutföranden, inbäddningar, svar och andra textåtgärder finns i referensen Azure OpenAI REST API. Följande scheman stöder bild-, ljud- och videoåtgärderna på den här sidan.
AzureAudioTranscriptionResponse
Resultatinformation för en åtgärd som transkriberade talat ljud till skriftlig text.
| Name | Type | Description | Obligatoriskt | Standardinställning |
|---|---|---|---|---|
| duration | number | Den totala varaktigheten för det ljud som bearbetas för att producera tillhörande transkriptionsinformation. | No | |
| language | string | Det talade språket som identifierades i transkriberade ljuddata. Detta uttrycks som en iso-639-1-språkkod med två bokstäver som "en" eller "fr". |
No | |
| Segment | array | En samling information om tidpunkt, sannolikheter och annan information om varje bearbetat ljudsegment. | No | |
| uppgift | object | Definierar möjliga beskrivningar för tillgängliga ljudåtgärdssvar. | No | |
| text | string | Transkriberad text för angivna ljuddata. | Ja | |
| Ord | array | En samling information om tidpunkten för varje bearbetat ord. | No |
AzureAudioTranslationResponse
Resultatinformation för en åtgärd som översatte talat ljud till skriftlig text.
| Name | Type | Description | Obligatoriskt | Standardinställning |
|---|---|---|---|---|
| duration | number | Den totala varaktigheten för det ljud som bearbetas för att producera tillhörande översättningsinformation. | No | |
| language | string | Det talade språket som identifierades i översatta ljuddata. Detta uttrycks som en iso-639-1-språkkod med två bokstäver som "en" eller "fr". |
No | |
| Segment | array | En samling information om tidpunkt, sannolikheter och annan information om varje bearbetat ljudsegment. | No | |
| uppgift | object | Definierar möjliga beskrivningar för tillgängliga ljudåtgärdssvar. | No | |
| text | string | Den översatta texten för angivna ljuddata. | Ja |
AzureErrorResponse
| Name | Type | Description | Obligatoriskt | Standardinställning |
|---|---|---|---|---|
| fel | object | Felinformationen. | No | |
| └– kod | string | Den distinkta, maskingenererade identifieraren för felet. | No | |
| └– inner_error | No | |||
| └– meddelande | string | Ett läsbart meddelande som är associerat med felet. | No | |
| └– param | string | Om tillämpligt, den indataparameter för begäran som är associerad med felet | No | |
| └– typ | enum | Objekttypen, alltid "error". Möjliga värden: error |
No |
AzureImagesResponse
| Name | Type | Description | Obligatoriskt | Standardinställning |
|---|---|---|---|---|
| bakgrund | enum | Endast GPT-image-1: bakgrundsparametern som används för bildgenereringen. Antingen transparent eller opaque.Möjliga värden: transparent, opaque |
No | |
| Skapad | integer | Unix-tidsstämpeln (i sekunder) för när avbildningen skapades. | Ja | |
| data | array | No | ||
| output_format | enum | Utdataformatet för bildgenereringen. Antingen png, webpeller jpeg.Möjliga värden: png, webp, jpeg |
No | |
| kvalitet | enum | Kvaliteten på avbildningen som genereras. Antingen low, mediumeller high.Möjliga värden: low, medium, high |
No | |
| size | enum | Storleken på avbildningen som genereras. Antingen 1024x1024, 1024x1536eller 1536x1024.Möjliga värden: 1024x1024, 1024x1536, 1536x1024 |
No | |
| användning | object | Endast för gpt-image-1-series-modeller används information om tokenanvändning för bildgenereringen. |
No | |
| └– input_tokens | integer | Antalet token (bilder och text) i indataprompten. | No | |
| └─ inmatningstokensdetaljer | object | Indatatoken innehåller detaljerad information för bildgenereringen. | No | |
| └– image_tokens | integer | Antalet bildtoken i indataprompten. | No | |
| └– text_tokens | integer | Antalet texttoken i indataprompten. | No | |
| └– output_tokens | integer | Antalet bildtoken i utdatabilden. | No | |
| └– totalt_antal_tokenar | integer | Det totala antalet token (bilder och text) som används för bildgenereringen. | No |
AzureOpenAIVideoGenerationErrorResponse
| Name | Type | Description | Obligatoriskt | Standardinställning |
|---|---|---|---|---|
| kod | string | Den distinkta, maskingenererade identifieraren för felet. | No | |
| inner_error | object | Om tillämpligt, ett uppströmsfel som härstammar från det här felet. | No | |
| └– kod | enum | Koden som är associerad med det inre felet. Möjliga värden: ResponsibleAIPolicyViolation |
No | |
| └─ felinformation | Resultatinformationen för innehållsfiltret som är associerad med det inre felet. | No | ||
| └– revised_prompt | string | Om tillämpligt, den ändrade prompten som används för generering. | No | |
| message | string | Ett läsbart meddelande som är associerat med felet. | No | |
| Param | string | Om tillämpligt, den indataparameter för begäran som är associerad med felet | No | |
| type | string | I förekommande fall det indataradsnummer som är associerat med felet. | No |
VideoGeneration
Ett videogenereringsresultat.
| Name | Type | Description | Obligatoriskt | Standardinställning |
|---|---|---|---|---|
| skapad_tid | integer | Den tid då videogenerationen skapades. | Ja | |
| height | integer | Videons höjd. | Ja | |
| id | string | ID:t för videogenerationen. | Ja | |
| job_id | string | ID:t för videogenereringsjobbet för den här videon. | Ja | |
| n_seconds | integer | Videogenereringens varaktighet. | Ja | |
| object | enum | Möjliga värden: video.generation |
Ja | |
| prompt | string | Uppmaningen för den här videogenerationen. | Ja | |
| width | integer | Videons bredd. | Ja |
VideoGenerationJob
Ett videogenereringsjobb.
| Name | Type | Description | Obligatoriskt | Standardinställning |
|---|---|---|---|---|
| skapad_tid | integer | Tiden då jobbet skapades. | Ja | |
| utgår_den | integer | Den tid då jobbet tas bort automatiskt från tjänsten. Videoinnehållet och metadata för jobbet bör lagras före det här datumet för att undvika dataförlust. | No | |
| failure_reason | sträng (se giltiga modeller nedan) | No | ||
| avslutad_vid | integer | Tiden då jobbet avslutades med alla videogenerationer. | No | |
| Generationer | array | De genererade videorna för det här jobbet. Talet beror på den angivna n_variants och generationernas skapandeframgång. | No | |
| height | integer | Videons höjd. | Ja | |
| id | string | Jobbets ID. | Ja | |
| inpaint_items | array | Valfria inpainting-objekt för det här videogenereringsjobbet. | No | |
| model | string | Namnet på distributionen som ska användas för det här videogenereringsjobbet. | Ja | |
| n_seconds | integer | Varaktigheten för videogenereringsjobbet. | Ja | |
| n_variants | integer | Antalet videor som ska skapas som varianter för det här videogenereringsjobbet. | Ja | |
| object | enum | Möjliga värden: video.generation.job |
Ja | |
| prompt | string | Uppmaningen för det här videogenereringsjobbet. | Ja | |
| status | object | Status för ett videogenereringsjobb. | Ja | |
| width | integer | Videons höjd. | Ja |
VideoGenerationJobList
En lista över videogenereringsjobb.
| Name | Type | Description | Obligatoriskt | Standardinställning |
|---|---|---|---|---|
| data | array | Listan över videogenereringsjobb. | Ja | |
| first_id | string | ID för det första jobbet på den aktuella sidan, om det är tillgängligt. | No | |
| har_mer | boolean | En flagga som anger om det finns fler jobb tillgängliga efter listan. | Ja | |
| last_id | string | ID:t för det senaste jobbet på den aktuella sidan, om det är tillgängligt. | No | |
| object | enum | Möjliga värden: list |
Ja |
Nästa steg
Lär dig mer om modeller och finjustering med REST-API:et. Läs mer om underlying modeller som driver Azure OpenAI.